package Perl6::Bible;
use strict;
use warnings;

our $VERSION = '0.10';

1;

__DATA__

=head1 NAME

Perl6::Bible - The Gospel according to Cabal

=head1 SYNOPSIS

    > p6bible s29

=head1 DESCRIPTION

This distribution contains all the latest Perl6 documentation and a utility
called C<p6bible> for viewing them. 

=head1 AUTHOR

Brian Ingerson <ingy@cpan.org>

=head1 COPYRIGHT

Copyright (c) 2005. Brian Ingerson. All rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

See http://www.perl.com/perl/misc/Artistic.html

=cut
